<?php
/**
 * The main theme functions file loads styles/scripts, allows some theme functionality and provides some helper functions.
 */
/**
 * This theme only works in WordPress 4.2 or later.
 */

if ( version_compare( $GLOBALS['wp_version'], '4.2', '<' ) ) {
    require get_template_directory() . '/inc/back-compat.php';
}

if ( ! isset( $content_width ) ) $content_width = 1170;


function truewest_getAssetsPath($path) {
    return get_template_directory_uri() . '/assets/' . $path;
}

function truewest_image($name) {
    return truewest_getAssetsPath('img/'.$name);
}

	/**
	 * Enqueue scripts and styles.
	 *
	 */
	function truewest_scripts() {
		global $wp_styles;
		
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
			wp_enqueue_script( 'comment-reply' );
	
		// Loads our bootstrap.
		wp_enqueue_style( 'truewest-bootstrap-style', truewest_getAssetsPath('bootstrap/css/bootstrap.min.css') );

		// Adds bootstrap JavaScript.
		wp_enqueue_script( 'truewest-bootstrap-js',truewest_getAssetsPath('bootstrap/js/bootstrap.min.js'), array( 'jquery' ) );
	
		// Loads our main stylesheet.
		wp_enqueue_style( 'truewest-style', get_stylesheet_uri() );
		
		/* Menu */
  		// Adds bootstrap JavaScript.
		wp_enqueue_script( 'truewest-menu-js',truewest_getAssetsPath('menu/script.js'), array( 'jquery' ) );
		wp_enqueue_style( 'truewest-menu-style',truewest_getAssetsPath('menu/styles.css'));
	
       	//Load Font CSS
		wp_enqueue_style('font-awesome.min', truewest_getAssetsPath('custom/css/font-awesome.min.css'));
		
		/* OWL */
		// Loads stylesheets.
			wp_enqueue_style( 'truewest-owl-style', truewest_getAssetsPath('owl-carousel/owl.carousel.css'));
			wp_enqueue_style( 'truewest-owl-theme', truewest_getAssetsPath('owl-carousel/owl.theme.css'));
			// OWL JS
			wp_enqueue_script( 'truewest-owl',  truewest_getAssetsPath('owl-carousel/owl.carousel.js'));
	
		// Custom JS
		wp_enqueue_script( 'truewest-custom',  truewest_getAssetsPath('custom/js/custom.js'));
	
	}
	
	add_action( 'wp_enqueue_scripts', 'truewest_scripts' );

	// Add Open Sans Google font
	function truewest_add_google_fonts() {
				
				wp_register_style('truewest-googleFonts-Montserrat', 'http://fonts.googleapis.com/css?family=Montserrat');
	 			wp_enqueue_style('truewest-googleFonts-Montserrat');
	
				wp_register_style('truewest-googleFonts-OpenSans', 'http://fonts.googleapis.com/css?family=Open+Sans');
	 			wp_enqueue_style('truewest-googleFonts-OpenSans');
	
			}
	 
	add_action('wp_print_styles', 'truewest_add_google_fonts');

  function truewest_setup(){
		//Navigation Menus
		register_nav_menus(array(
			'primary' => __('Primary Menu', 'truewest')
		));
	
		//Add featured image support
		add_theme_support('post-thumbnails');
	
		//This feature enables plugins and themes to manage the document title tag.
		add_theme_support('title-tag');
		
		//This feature adds RSS feed links to HTML <head>.
		add_theme_support( 'automatic-feed-links' );
	 
	
		add_theme_support('post-thumbnails');
		set_post_thumbnail_size( 710, 300, true ); 
		
		/*----------------------------
			 Add image sizes 
		 -----------------------------*/
		 
		add_image_size ( 'truewest-slider_image', 1100, 611, true);
		add_image_size ( 'truewest-aboutus_image', 1100, 550, true);
		add_image_size ( 'truewest-services_image', 325, 200, true);
		add_image_size ( 'truewest-gallery-image', 313, 284, true);
		add_image_size ( 'truewest-team_image_thumb', 217, 214, true);
		add_image_size ( 'truewest-contact_image', 521, 600, true);
		
  }
	
add_action( 'after_setup_theme', 'truewest_setup' ); 
	
 
	//Customize excerpt word count
	function custom_excerpt_length() {
		return 50; //50 words
	}
	
	add_filter('excerpt_length', 'custom_excerpt_length');

//Add our Widget Locations
function truewest_WidgetsInit() {

    register_sidebar(array(
        'name' => __('Footer Area', 'truewest'),
        'id' => 'footer_area',
   		'before_widget' => '<aside id="%1$s" class="footer_widget col-md-4 %2$s"  itemscope itemtype="http://schema.org/WPFooter">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title heading" itemprop="about">',
		'after_title'   => '</h3>',
    ));
    register_sidebar(array(
        'name' => __('Default Widget Area', 'truewest'),
        'id' => 'sidebar',
   		'before_widget' => '<aside id="%1$s" class="sidebar_widget %2$s"  itemscope itemtype="http://schema.org/WPSideBar">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title heading" itemprop="about">',
		  'after_title'   => '</h3>',
    ));
 

}

add_action('widgets_init', 'truewest_WidgetsInit');

/*---------------------------------------------
	 Custom Fucntions
----------------------------------------------*/
include_once( dirname( __FILE__ ) . '/theme-options.php' );
include('navthemes_fuctions.php');
